@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/Element.pm
-## Version v0.2.0
+## Version v0.2.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/04/25
-## Modified 2022/09/18
+## Modified 2022/09/20
 ## All rights reserved
 ## 
 ## 
@@ -35,7 +35,7 @@ BEGIN
     our $LOOK_LIKE_HTML = qr/^[[:blank:]\h]*\<\w+.*?\>/;
     our $LOOK_LIKE_IT_HAS_HTML = qr/\<\w+.*?\>/;
     our $ATTRIBUTE_NAME_RE = qr/\w[\w\-]*/;
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -1556,7 +1556,7 @@ sub _set_get_id : lvalue
                 $dummy = \1;
             }
             return( $dummy ) if( want( 'LVALUE' ) );
-            rreturn( $dummy );
+            Want::rreturn( $dummy );
         }
         else
         {
@@ -1564,14 +1564,14 @@ sub _set_get_id : lvalue
             $self->reset(1);
             my $dummy = \1;
             return( $dummy ) if( want( 'LVALUE' ) );
-            rreturn( $dummy );
+            Want::rreturn( $dummy );
         }
     }
     else
     {
         my $id = $self->new_scalar( $self->attributes->get( 'id' ) );
         return( $id ) if( want( 'LVALUE' ) );
-        rreturn( $id );
+        Want::rreturn( $id );
     }
 }
 
@@ -1624,7 +1624,7 @@ HTML::Object::Element - HTML Element Object
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
